@@ -2,9 +2,6 @@
 //!
 //! This module provides the primitives on which the public APIs are implemented.
 
-use std::cell::Cell;
-use std::ptr;
-
 use locale_config::{LanguageRange, Locale};
 
 use crate::allowed_url::{AllowedUrl, Href};
@@ -15,7 +12,7 @@ use crate::dpi::Dpi;
 use crate::drawing_ctx::DrawingCtx;
 use crate::error::{DefsLookupErrorKind, LoadingError, RenderingError};
 use crate::node::{CascadedValues, RsvgNode};
-use crate::rect::{IRect, Rect};
+use crate::rect::Rect;
 use crate::structure::{IntrinsicDimensions, Svg};
 use url::Url;
 
@@ -83,115 +80,6 @@ impl LoadOptions {
     }
 }
 
-// Keep in sync with rsvg.h:RsvgDimensionData
-#[repr(C)]
-pub struct RsvgDimensionData {
-    pub width: libc::c_int,
-    pub height: libc::c_int,
-    pub em: f64,
-    pub ex: f64,
-}
-
-impl RsvgDimensionData {
-    // This is not #[derive(Default)] to make it clear that it
-    // shouldn't be the default value for anything; it is actually a
-    // special case we use to indicate an error to the public API.
-    pub fn empty() -> RsvgDimensionData {
-        RsvgDimensionData {
-            width: 0,
-            height: 0,
-            em: 0.0,
-            ex: 0.0,
-        }
-    }
-}
-
-// Keep in sync with rsvg.h:RsvgPositionData
-#[repr(C)]
-pub struct RsvgPositionData {
-    pub x: libc::c_int,
-    pub y: libc::c_int,
-}
-
-// Keep in sync with rsvg.h:RsvgSizeFunc
-pub type RsvgSizeFunc = Option<
-    unsafe extern "C" fn(
-        inout_width: *mut libc::c_int,
-        inout_height: *mut libc::c_int,
-        user_data: glib_sys::gpointer,
-    ),
->;
-
-pub struct SizeCallback {
-    pub size_func: RsvgSizeFunc,
-    pub user_data: glib_sys::gpointer,
-    pub destroy_notify: glib_sys::GDestroyNotify,
-    pub in_loop: Cell<bool>,
-}
-
-impl SizeCallback {
-    pub fn new(
-        size_func: RsvgSizeFunc,
-        user_data: glib_sys::gpointer,
-        destroy_notify: glib_sys::GDestroyNotify,
-    ) -> Self {
-        SizeCallback {
-            size_func,
-            user_data,
-            destroy_notify,
-            in_loop: Cell::new(false),
-        }
-    }
-
-    pub fn call(&self, width: libc::c_int, height: libc::c_int) -> (libc::c_int, libc::c_int) {
-        unsafe {
-            let mut w = width;
-            let mut h = height;
-
-            if let Some(ref f) = self.size_func {
-                f(&mut w, &mut h, self.user_data);
-            };
-
-            (w, h)
-        }
-    }
-
-    pub fn start_loop(&self) {
-        assert!(!self.in_loop.get());
-        self.in_loop.set(true);
-    }
-
-    pub fn end_loop(&self) {
-        assert!(self.in_loop.get());
-        self.in_loop.set(false);
-    }
-
-    pub fn get_in_loop(&self) -> bool {
-        self.in_loop.get()
-    }
-}
-
-impl Default for SizeCallback {
-    fn default() -> SizeCallback {
-        SizeCallback {
-            size_func: None,
-            user_data: ptr::null_mut(),
-            destroy_notify: None,
-            in_loop: Cell::new(false),
-        }
-    }
-}
-
-impl Drop for SizeCallback {
-    fn drop(&mut self) {
-        unsafe {
-            if let Some(ref f) = self.destroy_notify {
-                f(self.user_data);
-            };
-        }
-    }
-}
-
 pub struct Handle {
     document: Document,
 }
@@ -217,77 +105,6 @@ impl Handle {
         }
     }
 
-    pub fn get_dimensions(
-        &self,
-        dpi: Dpi,
-        size_callback: &SizeCallback,
-        is_testing: bool,
-    ) -> Result<RsvgDimensionData, RenderingError> {
-        // This function is probably called from the cairo_render functions,
-        // or is being erroneously called within the size_func.
-        // To prevent an infinite loop we are saving the state, and
-        // returning a meaningless size.
-        if size_callback.get_in_loop() {
-            return Ok(RsvgDimensionData {
-                width: 1,
-                height: 1,
-                em: 1.0,
-                ex: 1.0,
-            });
-        }
-
-        size_callback.start_loop();
-
-        let res = self.get_dimensions_sub(None, dpi, size_callback, is_testing);
-
-        size_callback.end_loop();
-
-        res
-    }
-
-    pub fn get_dimensions_sub(
-        &self,
-        id: Option<&str>,
-        dpi: Dpi,
-        size_callback: &SizeCallback,
-        is_testing: bool,
-    ) -> Result<RsvgDimensionData, RenderingError> {
-        let (ink_r, _) = self.get_geometry_sub(id, dpi, is_testing)?;
-
-        let (w, h) = size_callback.call(ink_r.width as libc::c_int, ink_r.height as libc::c_int);
-
-        Ok(RsvgDimensionData {
-            width: w,
-            height: h,
-            em: ink_r.width,
-            ex: ink_r.height,
-        })
-    }
-
-    pub fn get_position_sub(
-        &self,
-        id: Option<&str>,
-        dpi: Dpi,
-        size_callback: &SizeCallback,
-        is_testing: bool,
-    ) -> Result<RsvgPositionData, RenderingError> {
-        if id.is_none() {
-            return Ok(RsvgPositionData { x: 0, y: 0 });
-        }
-
-        let (ink_r, _) = self.get_geometry_sub(id, dpi, is_testing)?;
-
-        let width = ink_r.width as libc::c_int;
-        let height = ink_r.height as libc::c_int;
-
-        size_callback.call(width, height);
-
-        Ok(RsvgPositionData {
-            x: ink_r.x as libc::c_int,
-            y: ink_r.y as libc::c_int,
-        })
-    }
-
     /// Returns (ink_rect, logical_rect)
     fn get_node_geometry_with_viewport(
         &self,
@@ -295,7 +112,7 @@ impl Handle {
         viewport: Rect,
         dpi: Dpi,
         is_testing: bool,
-    ) -> Result<(cairo::Rectangle, cairo::Rectangle), RenderingError> {
+    ) -> Result<(Rect, Rect), RenderingError> {
         let root = self.document.root();
 
         let target = cairo::ImageSurface::create(cairo::Format::Rgb24, 1, 1)?;
@@ -312,19 +129,16 @@ impl Handle {
         let ink_rect = bbox.ink_rect.unwrap_or_default();
         let logical_rect = bbox.rect.unwrap_or_default();
 
-        Ok((
-            cairo::Rectangle::from(ink_rect),
-            cairo::Rectangle::from(logical_rect),
-        ))
+        Ok((ink_rect, logical_rect))
     }
 
     /// Returns (ink_rect, logical_rect)
-    fn get_geometry_sub(
+    pub fn get_geometry_sub(
         &self,
         id: Option<&str>,
         dpi: Dpi,
         is_testing: bool,
-    ) -> Result<(cairo::Rectangle, cairo::Rectangle), RenderingError> {
+    ) -> Result<(Rect, Rect), RenderingError> {
         let node = self.get_node_or_root(id)?;
 
         let root = self.document.root();
@@ -337,9 +151,9 @@ impl Handle {
             if let Some((root_width, root_height)) =
                 node.borrow().get_impl::<Svg>().get_size(&values, dpi)
             {
-                let rect = IRect::from_size(root_width, root_height);
+                let rect = Rect::from_size(root_width, root_height);
 
-                return Ok((cairo::Rectangle::from(rect), cairo::Rectangle::from(rect)));
+                return Ok((rect, rect));
             }
         }
 
@@ -363,7 +177,14 @@ impl Handle {
     ) -> Result<(cairo::Rectangle, cairo::Rectangle), RenderingError> {
         let node = self.get_node_or_root(id)?;
         let viewport = Rect::from(*viewport);
-        self.get_node_geometry_with_viewport(&node, viewport, dpi, is_testing)
+
+        let (ink_rect, logical_rect) =
+            self.get_node_geometry_with_viewport(&node, viewport, dpi, is_testing)?;
+
+        Ok((
+            cairo::Rectangle::from(ink_rect),
+            cairo::Rectangle::from(logical_rect),
+        ))
     }
 
     fn lookup_node(&self, id: &str) -> Result<RsvgNode, DefsLookupErrorKind> {
@@ -399,32 +220,6 @@ impl Handle {
         }
     }
 
-    pub fn render_cairo_sub(
-        &self,
-        cr: &cairo::Context,
-        id: Option<&str>,
-        dpi: Dpi,
-        size_callback: &SizeCallback,
-        is_testing: bool,
-    ) -> Result<(), RenderingError> {
-        check_cairo_context(cr)?;
-
-        let dimensions = self.get_dimensions(dpi, size_callback, is_testing)?;
-        if dimensions.width == 0 || dimensions.height == 0 {
-            // nothing to render
-            return Ok(());
-        }
-
-        let viewport = cairo::Rectangle {
-            x: 0.0,
-            y: 0.0,
-            width: f64::from(dimensions.width),
-            height: f64::from(dimensions.height),
-        };
-
-        self.render_layer(cr, id, &viewport, dpi, is_testing)
-    }
-
     pub fn render_document(
         &self,
         cr: &cairo::Context,
